@@ -138,7 +138,7 @@ class ProfilePlugin(base_plugin.TBPlugin):
   def frontend_metadata(self):
     # TODO(#2338): Keep this in sync with the `registerDashboard` call
     # on the frontend until that call is removed.
-    return super(ProfilePlugin, self).frontend_metadata()._replace(
+    return base_plugin.FrontendMetadata(
         element_name='tf-profile-dashboard',
         disable_reload=True,
     )
